==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFormDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescription } from "./WebFormDataDescription";
/**
 * @hidden
 */
var WebFormDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDataDescriptionMetadata, _super);
    function WebFormDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDataDescriptionMetadata.b = function (a) {
        if (WebFormDataDescriptionMetadata.a == null) {
            WebFormDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDataDescriptionMetadata.c(WebFormDataDescriptionMetadata.a);
        }
        if (a.j(WebFormDataDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFormDataDescriptionMetadata.a);
    };
    WebFormDataDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FormData");
        a.item("Keys", "Array:object");
        a.item("Values", "Array:object");
    };
    WebFormDataDescriptionMetadata.d = function (a) {
        WebFormDataDescriptionMetadata.b(a);
        a.aa("WebFormData", function () { return new WebFormDataDescription(); });
        a.z("WebFormData", WebFormDataDescriptionMetadata.a);
    };
    WebFormDataDescriptionMetadata.$t = markType(WebFormDataDescriptionMetadata, 'WebFormDataDescriptionMetadata');
    WebFormDataDescriptionMetadata.a = null;
    return WebFormDataDescriptionMetadata;
}(Base));
export { WebFormDataDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFormDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescription } from "./WebFormDataDescription";
/**
 * @hidden
 */
var WebFormDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDataDescriptionMetadata, _super);
    function WebFormDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDataDescriptionMetadata.b = function (a) {
        if (WebFormDataDescriptionMetadata.a == null) {
            WebFormDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDataDescriptionMetadata.c(WebFormDataDescriptionMetadata.a);
        }
        if (a.k(WebFormDataDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFormDataDescriptionMetadata.a);
    };
    WebFormDataDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FormData");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Keys", "Array:object");
        a.item("Values", "Array:object");
    };
    WebFormDataDescriptionMetadata.d = function (a) {
        WebFormDataDescriptionMetadata.b(a);
        a.ac("WebFormData", function () { return new WebFormDataDescription(); });
        a.ab("WebFormData", WebFormDataDescriptionMetadata.a);
    };
    WebFormDataDescriptionMetadata.$t = markType(WebFormDataDescriptionMetadata, 'WebFormDataDescriptionMetadata');
    WebFormDataDescriptionMetadata.a = null;
    return WebFormDataDescriptionMetadata;
}(Base));
export { WebFormDataDescriptionMetadata };
